@@ -18,6 +18,7 @@ from . import utils
 from .exceptions import (
     CannotInferTicketNumberFromFolderName,
     GitCommandError,
+    JirafsError,
     LocalCopyOutOfDate,
     NotTicketFolderException
 )
@@ -114,9 +115,15 @@ def push(args, jira, path, **kwargs):
 @command('Run a command in this issue\'s git repository')
 def git(args, jira, path, **kwargs):
     parser = argparse.ArgumentParser()
-    _, extra = parser.parse_known_args(args)
+    parser.add_argument(
+        '--no-migrate',
+        dest='migrate',
+        default=True,
+        action='store_false',
+    )
+    args, extra = parser.parse_known_args(args)
 
-    folder = TicketFolder(path, jira)
+    folder = TicketFolder(path, jira, migrate=args.migrate)
     print(folder.run_git_command(*extra))
 
 
@@ -554,6 +561,8 @@ def main():
                 )
             )
             sys.exit(1)
+    except JirafsError as e:
+        print("Jirafs encountered an error processing your request: %s" % e)
 
     logger.debug(
         'Command %s(%s) finished in %s seconds',
